/**
 * @Description: 个人中心
 * @Author: 空白格
 * @Date: 2022-08-15 14:26:14
 * @LastEditors: 空白格
 * @LastEditTime: 2022-08-26 17:38:27
 * @FilePath: \veterans_client_web\src\api\PersonalCenter\index.js
 * @Copyright: Copyright (c) 2016~2022 by 空白格, All Rights Reserved.
 */
import request from '@/utils/request'

/**
 * 获取个人信息
 * @param {*} params
 * @returns
 */
export function getPersonInfoData(params) {
  return request({
    url: '/app/memberinfo',
    method: 'get',
    params
  })
}

/**
 * 获取个人积分
 * @param {*} params
 * @returns
 */
export function getPersonIntegralData(params) {
  return request({
    url: '/app/integral/total',
    method: 'get',
    params
  })
}

/**
 * 获取个人统计
 * @param {*} params
 * @returns
 */
export function getPersonStaticisData(params) {
  return request({
    url: '/app/memberinfo/getCountResult',
    method: 'get',
    params
  })
}

/**
 * 获取身份证信息
 * @param {*} params
 * @returns
 */
export function getIdInfo(params) {
  return request({
    url: `/app/veteEduc/idcard/${params.id}`,
    method: 'get'
  })
}

/**
 * 查询我投递列表
 * @param {*} params
 * @returns
 */
export function myDeliveredList(params) {
  return request({
    url: '/app/delivery/myDeliveredList',
    method: 'get',
    params
  })
}

/**
 * 查询我的面试列表
 * @param {*} params
 * @returns
 */
export function myInterviewList(params) {
  return request({
    url: '/app/delivery/myInterviewList',
    method: 'get',
    params
  })
}
/**
 * 保存求职意向
 * @param {*} params
 * @returns
 */
export function saveJobIntention(data) {
  return request({
    url: '/app/memberinfo/saveJobIntention',
    method: 'put',
    data
  })
}

/**
 * 保存自我评价
 * @param {*} params
 * @returns
 */
export function saveSelfAssessment(data) {
  return request({
    url: '/app/memberinfo/saveSelfAssessment',
    method: 'put',
    data
  })
}

/**
 * 我的培训列表
 * @param {*} params
 * @returns
 */
export function myTrainList(params) {
  return request({
    url: '/app/learnmember/myTrainList/' + params.type,
    method: 'get',
    params
  })
}

/**
 * 修改个人在职状态
 * @param {*} params
 * @returns
 */
export function updateJobStatus(data) {
  return request({
    url: '/app/memberinfo/updateJobStatus',
    method: 'put',
    data
  })
}

/**
 * 获取我的技能培训视频详情
 * @param {*} params
 * @returns
 */
export function getMyTrainVideoDetails(params) {
  return request({
    url: '/app/learncourse/getDetail/' + params.id,
    method: 'get',
    params
  })
}
